%% This is astronomyletters.cls, version December 13, 2023.
%% This LaTeX class is intended to emulate the layout of "Pis'ma v Astronomicheskii Zhurnal".
%% Written by Alexander Potekhin (Ioffe Institute) <palex-spb@yandex.ru>.
%% Please report any discovered bugs to the above address!
%% This class file can be freely used and redistributed
%%  according to the LaTeX Project Public License (LPPL).

\NeedsTeXFormat{LaTeX2e}

\ProvidesPackage{astronomyletters}[2023-12-13 LaTeX package for emulation of
Astronomy Letters]

\LoadClass[a4paper,twocolumn,twoside,12pt]{article}

\AtEndOfPackage{
\makeatletter
\renewcommand{\@oddfoot}{\small \phantom{xxx} \journame\hfill}
\renewcommand{\@evenfoot}{\small \hfill \journame\phantom{xxx}}
\makeatother
}

\RequirePackage{indentfirst}
\RequirePackage{abstract}
\RequirePackage[hang,flushmargin]{footmisc}
\RequirePackage{caption}
\AtEndOfPackage{
\captionsetup{labelsep=period,labelfont={bf,small},textfont=small,justification=raggedright,singlelinecheck=false}
}

\pagestyle{myheadings}
\textwidth=178mm
\textheight=250mm
\voffset=-23mm
\def\baselinestretch{.9}
\setlength{\oddsidemargin}{-10mm}
\setlength{\evensidemargin}{-10mm}
\setlength{\columnsep}{5.5mm}

\makeatletter
\newcommand{\nextauth}{%
 \@ifnextchar[{\nextauth@email}{\nextauth@nothing}%
}
\newcommand{\nextauth@nothing}[2]{%
  \phantom{,}#1$^{#2}$\hspace{-3pt}
}
\newcommand{\nextauth@email}[3][]{%
\if\relax\detokenize{#1}\relax
 \phantom{x}#2$^{#3}$
\else
 \phantom{x}#2$^{#3}$\thanks{E-mail: \texttt{#1}}\,\,%
\fi
}
\makeatother

\newcommand{\titles}[2][]{
\title{\expandafter{\Large\bf{#2}}}
\markright{\expandafter\MakeUppercase\expandafter{\small\hfill\rm #1 \hfill}}
}

\newcommand{\authors}[2][]{
   \author{\parbox{.9\linewidth}{\centering\normalsize%
     \textbf{%
 %    \copyright~\the\year{} ~ 
     #2}}}
   \markboth{\small\rm \hfill #1 \hfill}{}
   }


\newcounter{affil}
\setcounter{affil}{0}

\newcommand{\nextaffil}[1]{%
  \stepcounter{affil}
  {\normalsize$^{\arabic{affil}}$\textit{#1}}\\
}

\newcommand{\affiliations}[1]{
\date{\vspace*{-1ex}{
#1
}
\vspace{1ex}
  {\small \received}
}
}

\newcommand{\keywords}[1]{%
\phantom{x}\\
\phantom{x}\\
\noindent Keywords: \textit{#1}}
\newcommand{\doi}[1]{%
\phantom{x}\\
\phantom{x}\\
\noindent{\small\textbf{DOI:} #1}}

\newcommand{\wideabstract}[1]{
\twocolumn[
    \begin{onecolabstract}    
   \maketitle
   \noindent{\small
#1}
\vspace{\baselineskip}
\end{onecolabstract}
]
\saythanks % typesets any \thanks commands
}

%% Formatting sections' titles:
\makeatletter
\renewcommand\section{%
  \@startsection{section}% name
    {1}% level
    {0pt}% indent
    {-3.5ex plus -1ex minus -.2ex}% beforeskip
    {2.3ex plus.2ex}% afterskip
    {\centering\expandafter\MakeUppercase\expandafter}% style
  }
\renewcommand\subsection{%
  \@startsection{subsection}% name
    {2}% level
    {0pt}% indent
    {-3.5ex plus -1ex minus -.2ex}% beforeskip
    {2.3ex plus.2ex}% afterskip
    {\centering\slshape}% style
  }
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
    {-1ex\@plus -1ex \@minus -.2ex}%
    {-1.5ex \@plus -.2ex}% Formerly 1.5ex \@plus .2ex
    {\normalfont\normalsize\bfseries}% style
  }
\renewcommand{\@seccntformat}[1]{\csname the#1\endcsname.\,\,\,\,% put dot and space after section number
  \expandafter\ifx\csname c@#1\endcsname \c@subsubsection% decrease space before subsubsection title
    \!% decrease space before subsubsection title
  \fi
}
\makeatother

% ------------------
\AtBeginDocument{

\renewcommand{\figurename}{{\small\textbf{Fig.}}}
\renewcommand{\tablename}{{\small\textbf{Table}}}
\def\received{Received ??.??.20??;
revised ??.??.20??; accepted ??.??.20??}
\def\journame{ASTRONOMY LETTERS ~ Vol.~?? ~ No.~?? ~ 20??}
\renewcommand{\abstractname}{\vspace*{-8ex}}

%% \newenvironment{references}{
%% \vspace*{3ex}
%% \centerline{\small REFERENCES} 
%% \begin{enumerate}
%% \setlength{\itemsep}{-.5\parsep}
%% \small
%% \vspace*{-2ex}
%% }{\end{enumerate}}
%% \newcommand{\reference}{\item}

\newenvironment{references}{% \renewcommand\bibsection{\centerline{\small REFERENCES}}
\vspace*{2ex}
\begin{thebibliography}{99}
\setlength{\itemsep}{-.5\parsep}
\small
\vspace*{-1ex}
}{\end{thebibliography}}


% ------------------

% ABBREVIATIONS OF JOURNALS:
% BORROWED FROM pazh.sty prepared by S.Grebenev (IKI, Moscow; May 5, 1996)
%xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
\def\aap{\rm{Astron.\ Astrophys.}}
\def\aapr{\rm{Astron.\ Astrophys.\ Rev.}}
\def\aaps{\rm{Astron.\ Astrophys.\ Suppl.\ Ser.}}
\def\aj{\rm{Astron.\ J.}}
\def\ao{\rm{Appl.\ Optics}}
\def\apj{\rm{Astrophys.\ J.}}
\def\apjl{\rm{Astrophys.\ J.}}
\def\apjs{\rm{Astrophys.\ J.\ Suppl.\ Ser.}}
\def\apss{\rm{Astrophys.\ Space Sci.}}
\def\araa{\rm{Ann.\ Rev.\ Astron.\ Astrophys.}}
\def\asr{\rm{Adv.\ Space Res.}}
\def\astl{\rm{Astron.\ Lett.}}
\def\atel{\rm{Astron.\ Telegram}}
\def\baas{\rm{BAAS}}       
\def\iauc{\rm{IAU Circ.}}
\def\jrasc{\rm{JRASC}}     
\def\memras{\rm{MmRAS}}
\def\mnras{\rm{Mon.\ Not.\ R.\ Astron.\ Soc.}}
\def\nat{\hbox{Nature}}
\def\pra{\rm{Phys.\ Rev.\ A}}
\def\prb{\rm{Phys.\ Rev.\ B}}
\def\prc{\rm{Phys.\ Rev.\ C}}
\def\prd{\rm{Phys.\ Rev.\ D}}
\def\prl{\rm{Phys.\ Rev.\ Lett.}}    
\def\pasp{\rm{Publ.\ Astron.\ Soc.\ Pacific}}
\def\pasj{\rm{Publ.\ Astron.\ Soc.\ Japan}}
\def\qjras{\rm{QJRAS}}
\def\skytel{\rm{S\&T}}
\def\solphys{\rm{Solar~Phys.}}
\def\sovast{\rm{Sov.~Astron.}}
\def\sval{\rm{Sov.~Astron.\ Lett.}}
\def\ssr{\rm{Space~Sci.\ Rev.}}
\def\zap{\rm{ZAp}}
}

